==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestJobRelatedActions.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import org.junit.Test;
import org.oasisOpen.docs.wsrf.rp2.GetResourcePropertyDocumentResponseDocument;
import org.unigrids.x2006.x04.services.jms.JobPropertiesDocument;

import de.fzj.unicore.ucc.UCC;
import de.fzj.unicore.ucc.util.EmbeddedTestBase;
import eu.unicore.bugsreporter.annotation.FunctionalTest;

/**
 * Functional tests for the UCC actions. 
 * These run against an embedded UNICORE instance.
 */
public class TestJobRelatedActions extends EmbeddedTestBase {
		
	@FunctionalTest(id="http://testRunSimpleJob", description="Connects to the test server and runs a simple job")
	@Test
	public void test_Run(){
		connect();
		runDate();
	}

	@FunctionalTest(id="http://testRunJobWithUploads", description="Runs a job with file uploads")
	@Test
	public void test_Run_JobWithUploads(){
		connect();
		run("src/test/resources/jobs/date-with-uploads.u", false);
	}

	@FunctionalTest(id="http://testRunJobWithU6Staging", description="Runs a job with file staging from/to u6")
	@Test
	public void test_Run_WithU6Staging(){
		connect();
		upload("src/test/resources/testfiles/file1", "u6://UCC-Test/WORK/file1", true);
		run("src/test/resources/jobs/date-with-u6-staging.u", true);
	}
	
	@FunctionalTest(id="http://testRunJobWithErrorInStageOut", description="Runs a job using the failonerror flag")
	@Test
	public void test_Run_WithErrorInStageOut(){
		connect();
		run("src/test/resources/jobs/date-with-error-in-staging.u", true);
	}
	
	@FunctionalTest(id="http://testRunJobWithWildcardExports", description="Runs a job and export results using wildcards")
	@Test
	public void test_Run_JobWithWildcardExports(){
		connect();
		run("src/test/resources/jobs/date-with-wildcard-exports.u", false);
	}
	
	@FunctionalTest(id="testListJobs", description="Tests list-job command")
	@Test
	public void test_Run_and_ListJobs(){
		connect();
		runDate();
		
		String[] args=new String[]{"list-jobs", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testRunJSDL", description="Runs a job defined in a JSDL file")
	@Test
	public void test_Run_JSDL(){
		connect();
		String[] args=new String[]{"run",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-j","src/test/resources/jobs/date.jsdl",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testRunAsync", description="Runs a job in async mode")
	@Test
	public void test_Run_Async(){
		connect();

		String[] args=new String[]{"run", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/date.u",
				"-a"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		String id=Run.getLastJobAddress();
		int c=0;
		do{

			args=new String[]{"get-status", "-v",
					"-c", "src/test/resources/conf/userprefs.embedded",
					id,
			};
			UCC.main(args);
			assertEquals(Integer.valueOf(0),UCC.exitCode);
			c++;
			
		}while(c<5 && ! GetStatus.lastStatus.contains("SUCCESSFUL"));


		args=new String[]{"get-output", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				id,
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

	}

	@FunctionalTest(id="testAbort", description="Tests the abort command")
	@Test
	public void test_Run_and_Abort(){
		connect();

		String[] args=new String[]{"run", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/sleep.u",
				"-a"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		
		args=new String[]{"abort-job", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				Run.getLastJobAddress(),
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}
	
	protected String createNewUspace(){
		String[] args=new String[]{"run",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/date.u",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		args=new String[]{"wsrf", "getproperties", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				Run.getLastJobAddress(),
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		try{
			GetResourcePropertyDocumentResponseDocument d=GetResourcePropertyDocumentResponseDocument.Factory.parse(WSRF.getLastProperties());
			JobPropertiesDocument jd= JobPropertiesDocument.Factory.parse(d.getGetResourcePropertyDocumentResponse().newInputStream());
			return jd.getJobProperties().getWorkingDirectoryReference().getAddress().getStringValue();
		}catch(Exception ex){
			ex.printStackTrace();
			fail(); 
		}
		return null;
	}

}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestJobRelatedActions.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.io.FileUtils;
import org.junit.Test;
import org.oasisOpen.docs.wsrf.rp2.GetResourcePropertyDocumentResponseDocument;
import org.unigrids.x2006.x04.services.jms.JobPropertiesDocument;

import de.fzj.unicore.ucc.UCC;
import de.fzj.unicore.ucc.util.EmbeddedTestBase;
import de.fzj.unicore.ucc.util.MockReservation;
import eu.unicore.bugsreporter.annotation.FunctionalTest;
import eu.unicore.bugsreporter.annotation.RegressionTest;

/**
 * Functional tests for the UCC actions. 
 * These run against an embedded UNICORE instance.
 */
public class TestJobRelatedActions extends EmbeddedTestBase {

	@FunctionalTest(id="http://testRunSimpleJob", description="Connects to the test server and runs a simple job")
	@Test
	public void test_Run(){
		connect();
		runDate();
	}

	@FunctionalTest(id="http://testRunMultipleJobs", description="Connects to the test server and runs several " +
			"jobs using a single run command")
	@Test
	public void test_RunMulti(){
		connect();
		String job="src/test/resources/jobs/date.u";
		String[] args=new String[]{"run",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-a",
				job,job,job
		};		
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="http://testRunJobFromStdin", description="Reads a job from stdin and runs in")
	@Test
	public void test_Run_JobFromStdin()throws IOException{
		connect();
		InputStream in=System.in;
		FileInputStream fis=new FileInputStream("src/test/resources/jobs/date.u");
		System.setIn(fis);
		String[] args=new String[]{"run","-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
		};		
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		System.setIn(in);
		fis.close();
	}
	
	@FunctionalTest(id="http://testRunJobWithUploads", description="Runs a job with file uploads")
	@Test
	public void test_Run_JobWithUploads(){
		connect();
		run("src/test/resources/jobs/date-with-uploads.u", false);
	}

	@FunctionalTest(id="http://testRunJobWithU6Staging", description="Runs a job with file staging from/to u6")
	@Test
	public void test_Run_WithU6Staging(){
		connect();
		systemInfo();
		listStorages();
		upload("src/test/resources/testfiles/file1", "u6://UCC-TEST/WORK/file1", true);
		run("src/test/resources/jobs/date-with-u6-staging.u", true);
	}

	@FunctionalTest(id="http://testRunJobWithErrorInStageOut", description="Runs a job using the failonerror flag")
	@Test
	public void test_Run_WithErrorInStageOut(){
		connect();
		run("src/test/resources/jobs/date-with-error-in-staging.u", true);
	}
	
	@FunctionalTest(id="http://testRunJobWithWildcardExports", description="Runs a job and export results using wildcards")
	@Test
	public void test_Run_JobWithWildcardExports(){
		connect();
		run("src/test/resources/jobs/date-with-wildcard-exports.u", false);
	}
	
	@FunctionalTest(id="testListJobs", description="Tests list-job command")
	@Test
	public void test_Run_and_ListJobs(){
		connect();
		runDate();
		
		String[] args=new String[]{"list-jobs", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testRunJSDL", description="Runs a job defined in a JSDL file")
	@Test
	public void test_Run_JSDL(){
		connect();
		String[] args=new String[]{"run",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-j","src/test/resources/jobs/date.jsdl",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testRunAsync", description="Runs a job in async mode")
	@Test
	public void test_Run_Async(){
		connect();

		String[] args=new String[]{"run", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/date.u",
				"-a"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		String id1=Run.getLastJobAddress();
		
		args=new String[]{"run", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/date.u",
				"-a"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		String id2=Run.getLastJobAddress();
		
		
		int c=0;
		do{

			args=new String[]{"get-status",
					"-c", "src/test/resources/conf/userprefs.embedded",
					id1,id2,
			};
			UCC.main(args);
			assertEquals(Integer.valueOf(0),UCC.exitCode);
			c++;
			try{
				Thread.sleep(2000);
			}catch(InterruptedException i){};

		}while(c<5 && !GetStatus.allSuccessful);


		args=new String[]{"get-output", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				id1, id2
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

	}

	@RegressionTest(url="https://sourceforge.net/tracker/?func=detail&aid=3570378&group_id=102081&atid=633902",
			        id=3570378, 
			        description="Runs a job in async mode, using .job file, local import is missing on get-status")
	@Test
	public void test_Run_Async_MissingLocalFile()throws IOException{
		connect();
		File tmp=new File("target/temp-file-for-upload");
		FileUtils.writeStringToFile(tmp, "test123");
		
		String[] args=new String[]{"run", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/date-with-uploads-tmpfile.u",
				"-a"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		//remove local file, should not cause problems in get-status and get-outcome
		boolean delete=tmp.delete();
		if(!delete)System.out.println("Warning, did not delete file");
		
		String id1=Run.getLastJobFile();
				
		int c=0;
		do{

			args=new String[]{"get-status",
					"-c", "src/test/resources/conf/userprefs.embedded",
					id1
			};
			UCC.main(args);
			assertEquals(Integer.valueOf(0),UCC.exitCode);
			c++;
			try{
				Thread.sleep(2000);
			}catch(InterruptedException i){};

		}while(c<5 && !GetStatus.allSuccessful);


		args=new String[]{"get-output", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				id1
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

	}


	@FunctionalTest(id="testAbort", description="Tests the abort command")
	@Test
	public void test_Run_and_Abort(){
		connect();

		String[] args=new String[]{"run", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/sleep.u",
				"-a"
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);


		args=new String[]{"abort-job", "-v", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				Run.getLastJobAddress(),
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}

	@FunctionalTest(id="testReservation", description="Tests the Reservation command")
	@Test
	public void test_Reservation(){
		connect();

		//check first with missing start time
		String[] args=new String[]{"reservation", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/reservation1.u",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(1),UCC.exitCode);

		//now the real reservation
		args=new String[]{"reservation", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-S", "12:00",
				"-s", "UCC-TEST",
				"src/test/resources/jobs/reservation1.u",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		String resID=Reservation.lastReservationID;
		assertNotNull(resID);

		MockReservation.queries.set(0);
		
		//list reservations
		args=new String[]{"reservation", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-l",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		assertEquals(Integer.valueOf(1), Reservation.lastNumberOfReservations);
		assertEquals(1, MockReservation.queries.get());
		
		//get properties of last reservation
		args=new String[]{"wsrf", "g",
				"-c", "src/test/resources/conf/userprefs.embedded",
				Reservation.lastReservationURL,
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		
		//delete last reservation
		args=new String[]{"reservation", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-d",
				resID,
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		//check it is deleted
		args=new String[]{"reservation", "-v",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-l",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
		assertEquals(Integer.valueOf(0), Reservation.lastNumberOfReservations);
		
		// check list reservations on non-existent site
		args=new String[]{"reservation",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-l",
				"-s", "NO_SUCH_SITE",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);
	}



	protected String createNewUspace(){
		String[] args=new String[]{"run",
				"-c", "src/test/resources/conf/userprefs.embedded",
				"src/test/resources/jobs/date.u",
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		args=new String[]{"wsrf", "getproperties", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				Run.getLastJobAddress(),
		};
		UCC.main(args);
		assertEquals(Integer.valueOf(0),UCC.exitCode);

		try{
			GetResourcePropertyDocumentResponseDocument d=GetResourcePropertyDocumentResponseDocument.Factory.parse(WSRF.getLastProperties());
			JobPropertiesDocument jd= JobPropertiesDocument.Factory.parse(d.getGetResourcePropertyDocumentResponse().newInputStream());
			return jd.getJobProperties().getWorkingDirectoryReference().getAddress().getStringValue();
		}catch(Exception ex){
			ex.printStackTrace();
			fail(); 
		}
		return null;
	}

}
